==> geant4-v11.3.2.tar.gz: geant4-v11.3.2/source/geometry/magneticfield/sources.cmake <==
# - G4magneticfield module build definition

# Define the Geant4 Module.
geant4_add_module(G4magneticfield
  PUBLIC_HEADERS
    G4BFieldIntegrationDriver.hh
    G4BFieldIntegrationDriver.icc
    G4BogackiShampine23.hh
    G4BogackiShampine45.hh
    G4BorisScheme.hh
    G4BorisScheme.icc
    G4BorisDriver.hh
    G4BorisDriver.icc
    G4BulirschStoer.hh
    G4BulirschStoer.icc
    G4BulirschStoerDriver.hh
    G4BulirschStoerDriver.icc
    G4CachedMagneticField.hh
    G4CashKarpRKF45.hh
    G4ChargeState.hh
    G4ChordFinder.hh
    G4ChordFinder.icc
    G4ChordFinderDelegate.hh
    G4ChordFinderDelegate.icc
    G4ClassicalRK4.hh
    G4ConstRK4.hh
    G4DELPHIMagField.hh
    G4DoLoMcPriRK34.hh
    G4DormandPrince745.hh
    G4DormandPrinceRK56.hh
    G4DormandPrinceRK78.hh
    G4DriverReporter.hh
    G4ElectricField.hh
    G4ElectroMagneticField.hh
    G4EqEMFieldWithEDM.hh
    G4EqEMFieldWithSpin.hh
    G4EqGravityField.hh
    G4EqMagElectricField.hh
    G4EquationOfMotion.hh
    G4EquationOfMotion.icc
    G4ErrorMag_UsualEqRhs.hh
    G4ExactHelixStepper.hh
    G4ExplicitEuler.hh
    G4Field.hh
    G4FieldBuilder.hh
    G4FieldBuilderMessenger.hh
    G4FieldManager.hh
    G4FieldManager.icc
    G4FieldManagerStore.hh
    G4FieldParameters.hh
    G4FieldParametersMessenger.hh
    G4FieldSetup.hh
    G4FieldSetupMessenger.hh
    G4FieldTrack.hh
    G4FieldTrack.icc
    G4FieldUtils.hh
    G4FieldUtils.icc
    G4FSALBogackiShampine45.hh
    G4FSALDormandPrince745.hh
    G4FSALIntegrationDriver.hh
    G4FSALIntegrationDriver.icc
    G4VFSALIntegrationStepper.hh
    G4VFSALIntegrationStepper.icc
    G4HarmonicPolMagField.hh
    G4HelixExplicitEuler.hh
    G4HelixHeum.hh
    G4HelixImplicitEuler.hh
    G4HelixMixedStepper.hh
    G4HelixSimpleRunge.hh
    G4ImplicitEuler.hh
    G4IntegrationDriver.hh
    G4IntegrationDriver.icc
    G4InterpolationDriver.hh
    G4InterpolationDriver.icc
    G4LineCurrentMagField.hh
    G4LineSection.hh
    G4MagErrorStepper.hh
    G4MagErrorStepper.icc
    G4MagHelicalStepper.hh
    G4MagHelicalStepper.icc
    G4MagIntegratorDriver.hh
    G4MagIntegratorDriver.icc
    G4MagIntegratorStepper.hh
    G4MagIntegratorStepper.icc
    G4Mag_EqRhs.hh
    G4Mag_SpinEqRhs.hh
    G4Mag_UsualEqRhs.hh
    G4ModifiedMidpoint.hh
    G4ModifiedMidpoint.icc
    G4MonopoleEq.hh
    G4MagneticField.hh
    G4NystromRK4.hh
    G4NystromRK4.icc
    G4OldMagIntDriver.hh
    G4OldMagIntDriver.icc
    G4QuadrupoleMagField.hh
    G4RepleteEofM.hh
    G4SextupoleMagField.hh
    G4RKG3_Stepper.hh
    G4RK547FEq1.hh
    G4RK547FEq2.hh
    G4RK547FEq3.hh
    G4RKIntegrationDriver.hh
    G4RKIntegrationDriver.icc
    G4SimpleHeum.hh
    G4SimpleRunge.hh
    G4TExplicitEuler.hh
    G4TSimpleHeum.hh
    G4TSimpleRunge.hh
    G4TCashKarpRKF45.hh
    G4TClassicalRK4.hh
    G4TDormandPrince45.hh
    G4TMagFieldEquation.hh
    G4TMagErrorStepper.hh
    G4TQuadrupoleMagField.hh
    G4TUniformMagneticField.hh
    G4TCachedMagneticField.hh
    G4TrialsCounter.hh
    G4TrialsCounter.icc
    G4TsitourasRK45.hh
    G4UniformElectricField.hh
    G4UniformGravityField.hh
    G4UniformMagField.hh
    G4VIntegrationDriver.hh
    # QSS - headers
    G4QSSDriver.hh
    G4QSSDriver.icc
    G4QSSDriverCreator.hh
    G4QSStepper.hh
    G4QSS2.hh
    G4QSS3.hh
    G4QSS_CustomStats.hh
    G4qss_misc.hh
    G4QSSMessenger.hh
  SOURCES
    G4BFieldIntegrationDriver.cc
    G4BogackiShampine23.cc
    G4BogackiShampine45.cc
    G4BorisDriver.cc
    G4BorisScheme.cc
    G4BulirschStoer.cc
    G4CachedMagneticField.cc
    G4CashKarpRKF45.cc
    G4ChargeState.cc
    G4ChordFinder.cc
    G4ClassicalRK4.cc
    G4ConstRK4.cc
    G4DELPHIMagField.cc
    G4DoLoMcPriRK34.cc
    G4DormandPrince745.cc
    G4DormandPrinceRK56.cc
    G4DormandPrinceRK78.cc
    G4DriverReporter.cc
    G4ElectricField.cc
    G4ElectroMagneticField.cc
    G4EqEMFieldWithEDM.cc
    G4EqEMFieldWithSpin.cc
    G4EqGravityField.cc
    G4EqMagElectricField.cc
    G4EquationOfMotion.cc
    G4ErrorMag_UsualEqRhs.cc
    G4ExactHelixStepper.cc
    G4ExplicitEuler.cc
    G4Field.cc
    G4FieldBuilder.cc
    G4FieldBuilderMessenger.cc
    G4FieldManager.cc
    G4FieldManagerStore.cc
    G4FieldParameters.cc
    G4FieldParametersMessenger.cc
    G4FieldSetup.cc
    G4FieldSetupMessenger.cc
    G4FieldTrack.cc
    G4FieldUtils.cc
    G4FSALBogackiShampine45.cc
    G4FSALDormandPrince745.cc
    G4VFSALIntegrationStepper.cc
    G4HarmonicPolMagField.cc
    G4HelixExplicitEuler.cc
    G4HelixHeum.cc
    G4HelixImplicitEuler.cc
    G4HelixMixedStepper.cc
    G4HelixSimpleRunge.cc
    G4ImplicitEuler.cc
    G4LineCurrentMagField.cc
    G4LineSection.cc
    G4MagErrorStepper.cc
    G4MagHelicalStepper.cc
    G4MagIntegratorDriver.cc
    G4MagIntegratorStepper.cc
    G4Mag_EqRhs.cc
    G4Mag_SpinEqRhs.cc
    G4Mag_UsualEqRhs.cc
    G4MagneticField.cc
    G4ModifiedMidpoint.cc
    G4MonopoleEq.cc
    G4NystromRK4.cc
    G4OldMagIntDriver.cc
    G4QuadrupoleMagField.cc
    G4QSSDriverCreator.cc
    G4RepleteEofM.cc
    G4RKG3_Stepper.cc
    G4RK547FEq1.cc
    G4RK547FEq2.cc
    G4RK547FEq3.cc
    G4SextupoleMagField.cc
    G4SimpleHeum.cc
    G4SimpleRunge.cc
    G4TrialsCounter.cc
    G4TsitourasRK45.cc
    G4UniformElectricField.cc
    G4UniformGravityField.cc
    G4UniformMagField.cc
    G4VIntegrationDriver.cc
    G4QSStepper.cc
    G4QSS3.cc
    G4QSSMessenger.cc
)

geant4_module_link_libraries(G4magneticfield PUBLIC G4globman G4intercoms
  PRIVATE G4geometrymng)
# List any source specific properties here
# For new system, must explicitly add path for generated header
geant4_module_include_directories(G4magneticfield PUBLIC
        $<BUILD_INTERFACE:${CMAKE_CURRENT_BINARY_DIR}/include>
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/particles/management/include>
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/intercoms/include>	
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/track/include>
)

==> geant4-v11.4.0.tar.gz: geant4-v11.4.0/source/geometry/magneticfield/sources.cmake <==
# - G4magneticfield module build definition

# Define the Geant4 Module.
geant4_add_module(G4magneticfield
  PUBLIC_HEADERS
    G4BFieldIntegrationDriver.hh
    G4BFieldIntegrationDriver.icc
    G4BogackiShampine23.hh
    G4BogackiShampine45.hh
    G4BorisScheme.hh
    G4BorisScheme.icc
    G4BorisDriver.hh
    G4BorisDriver.icc
    G4BulirschStoer.hh
    G4BulirschStoer.icc
    G4BulirschStoerDriver.hh
    G4BulirschStoerDriver.icc
    G4CachedMagneticField.hh
    G4CashKarpRKF45.hh
    G4ChargeState.hh
    G4ChargeState.icc
    G4ChordFinder.hh
    G4ChordFinder.icc
    G4ChordFinderDelegate.hh
    G4ChordFinderDelegate.icc
    G4ClassicalRK4.hh
    G4ConstRK4.hh
    G4DELPHIMagField.hh
    G4DoLoMcPriRK34.hh
    G4DormandPrince745.hh
    G4DormandPrinceRK56.hh
    G4DormandPrinceRK78.hh
    G4DriverReporter.hh
    G4ElectricField.hh
    G4ElectroMagneticField.hh
    G4EqEMFieldWithEDM.hh
    G4EqEMFieldWithSpin.hh
    G4EqGravityField.hh
    G4EqMagElectricField.hh
    G4EquationOfMotion.hh
    G4EquationOfMotion.icc
    G4ErrorMag_UsualEqRhs.hh
    G4ExactHelixStepper.hh
    G4ExplicitEuler.hh
    G4Field.hh
    G4FieldBuilder.hh
    G4FieldBuilderMessenger.hh
    G4FieldManager.hh
    G4FieldManager.icc
    G4FieldManagerStore.hh
    G4FieldParameters.hh
    G4FieldParameters.icc
    G4FieldParametersMessenger.hh
    G4FieldSetup.hh
    G4FieldSetupMessenger.hh
    G4FieldTrack.hh
    G4FieldTrack.icc
    G4FieldUtils.hh
    G4FieldUtils.icc
    G4FSALBogackiShampine45.hh
    G4FSALDormandPrince745.hh
    G4FSALIntegrationDriver.hh
    G4FSALIntegrationDriver.icc
    G4VFSALIntegrationStepper.hh
    G4VFSALIntegrationStepper.icc
    G4HarmonicPolMagField.hh
    G4HelixExplicitEuler.hh
    G4HelixHeum.hh
    G4HelixImplicitEuler.hh
    G4HelixMixedStepper.hh
    G4HelixSimpleRunge.hh
    G4ImplicitEuler.hh
    G4IntegrationDriver.hh
    G4IntegrationDriver.icc
    G4InterpolationDriver.hh
    G4InterpolationDriver.icc
    G4LineCurrentMagField.hh
    G4LineSection.hh
    G4MagErrorStepper.hh
    G4MagErrorStepper.icc
    G4MagHelicalStepper.hh
    G4MagHelicalStepper.icc
    G4MagIntegratorDriver.hh
    G4MagIntegratorDriver.icc
    G4MagIntegratorStepper.hh
    G4MagIntegratorStepper.icc
    G4Mag_EqRhs.hh
    G4Mag_SpinEqRhs.hh
    G4Mag_UsualEqRhs.hh
    G4ModifiedMidpoint.hh
    G4ModifiedMidpoint.icc
    G4MonopoleEq.hh
    G4MagneticField.hh
    G4NystromRK4.hh
    G4NystromRK4.icc
    G4OldMagIntDriver.hh
    G4OldMagIntDriver.icc
    G4QuadrupoleMagField.hh
    G4RepleteEofM.hh
    G4SextupoleMagField.hh
    G4RKG3_Stepper.hh
    G4RK547FEq1.hh
    G4RK547FEq2.hh
    G4RK547FEq3.hh
    G4RKIntegrationDriver.hh
    G4RKIntegrationDriver.icc
    G4SimpleHeum.hh
    G4SimpleRunge.hh
    G4TExplicitEuler.hh
    G4TSimpleHeum.hh
    G4TSimpleRunge.hh
    G4TCashKarpRKF45.hh
    G4TClassicalRK4.hh
    G4TDormandPrince45.hh
    G4TMagFieldEquation.hh
    G4TMagErrorStepper.hh
    G4TQuadrupoleMagField.hh
    G4TUniformMagneticField.hh
    G4TCachedMagneticField.hh
    G4TrialsCounter.hh
    G4TrialsCounter.icc
    G4TsitourasRK45.hh
    G4UniformElectricField.hh
    G4UniformGravityField.hh
    G4UniformMagField.hh
    G4VIntegrationDriver.hh
    # QSS - headers
    G4QSSDriver.hh
    G4QSSDriver.icc
    G4QSStepper.hh
    G4QSStepper.icc
    G4QSS2.hh
    G4QSS3.hh
    G4QSS_CustomStats.hh
    G4qss_misc.hh
    G4QSSMessenger.hh
    G4QSSParameters.hh
    G4QSSubstepStruct.hh
    G4QSSubstepStruct.icc
  SOURCES
    G4BFieldIntegrationDriver.cc
    G4BogackiShampine23.cc
    G4BogackiShampine45.cc
    G4BorisDriver.cc
    G4BorisScheme.cc
    G4BulirschStoer.cc
    G4CachedMagneticField.cc
    G4CashKarpRKF45.cc
    G4ChargeState.cc
    G4ChordFinder.cc
    G4ClassicalRK4.cc
    G4ConstRK4.cc
    G4DELPHIMagField.cc
    G4DoLoMcPriRK34.cc
    G4DormandPrince745.cc
    G4DormandPrinceRK56.cc
    G4DormandPrinceRK78.cc
    G4DriverReporter.cc
    G4ElectricField.cc
    G4ElectroMagneticField.cc
    G4EqEMFieldWithEDM.cc
    G4EqEMFieldWithSpin.cc
    G4EqGravityField.cc
    G4EqMagElectricField.cc
    G4EquationOfMotion.cc
    G4ErrorMag_UsualEqRhs.cc
    G4ExactHelixStepper.cc
    G4ExplicitEuler.cc
    G4Field.cc
    G4FieldBuilder.cc
    G4FieldBuilderMessenger.cc
    G4FieldManager.cc
    G4FieldManagerStore.cc
    G4FieldParameters.cc
    G4FieldParametersMessenger.cc
    G4FieldSetup.cc
    G4FieldSetupMessenger.cc
    G4FieldTrack.cc
    G4FieldUtils.cc
    G4FSALBogackiShampine45.cc
    G4FSALDormandPrince745.cc
    G4VFSALIntegrationStepper.cc
    G4HarmonicPolMagField.cc
    G4HelixExplicitEuler.cc
    G4HelixHeum.cc
    G4HelixImplicitEuler.cc
    G4HelixMixedStepper.cc
    G4HelixSimpleRunge.cc
    G4ImplicitEuler.cc
    G4LineCurrentMagField.cc
    G4LineSection.cc
    G4MagErrorStepper.cc
    G4MagHelicalStepper.cc
    G4MagIntegratorDriver.cc
    G4MagIntegratorStepper.cc
    G4Mag_EqRhs.cc
    G4Mag_SpinEqRhs.cc
    G4Mag_UsualEqRhs.cc
    G4MagneticField.cc
    G4ModifiedMidpoint.cc
    G4MonopoleEq.cc
    G4NystromRK4.cc
    G4OldMagIntDriver.cc
    G4QuadrupoleMagField.cc
    G4RepleteEofM.cc
    G4RKG3_Stepper.cc
    G4RK547FEq1.cc
    G4RK547FEq2.cc
    G4RK547FEq3.cc
    G4SextupoleMagField.cc
    G4SimpleHeum.cc
    G4SimpleRunge.cc
    G4TrialsCounter.cc
    G4TsitourasRK45.cc
    G4UniformElectricField.cc
    G4UniformGravityField.cc
    G4UniformMagField.cc
    G4VIntegrationDriver.cc
    G4QSStepper.cc
    G4QSS3.cc
    G4QSSMessenger.cc
    G4QSSParameters.cc
)

geant4_module_link_libraries(G4magneticfield PUBLIC G4globman G4intercoms
  PRIVATE G4geometrymng)
# List any source specific properties here
# For new system, must explicitly add path for generated header
geant4_module_include_directories(G4magneticfield PUBLIC
        $<BUILD_INTERFACE:${CMAKE_CURRENT_BINARY_DIR}/include>
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/particles/management/include>
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/intercoms/include>	
        $<BUILD_INTERFACE:${PROJECT_SOURCE_DIR}/source/track/include>
)
